import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';

const csvUrl =
  'https://gist.githubusercontent.com/srividyamadas/936edc198ab69bde2817ac18e039c690/raw/99dbd2fc205943275c26d1df2137f1b714b77ed1/gistfile1.txt';

const parseRow = (d) => {
  return {
    state: d.State,
    2020: +d['2020'],
    2021: +d['2021'],
    2022: +d['2022'],
    2023: +d['2023'],
    2024: +d['2024'],
  };
};

const width = window.innerWidth * 0.8;
const height = window.innerHeight * 0.8;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d['2020']) // X-axis: 2020
    .yValue((d) => d['2024']) // Y-axis: 2024
    .margin({
      top: 20,
      right: 20,
      bottom: 40,
      left: 50,
    })
    .radius(5);

  svg.call(plot);
};

main();
